@@ -204,6 +204,12 @@ func (ssm *sameSnapshotMutation) mustWrite(step *deploy.SameStep) bool {
 		return true
 	}
 
+	// We need to persist the changes if CustomTimes have changed
+	if old.RetainOnDelete != new.RetainOnDelete {
+		logging.V(9).Infof("SnapshotManager: mustWrite() true because of RetainOnDelete")
+		return true
+	}
+
 	contract.Assert(old.ID == new.ID)
 
 	// If this resource's provider has changed, we must write the checkpoint. This can happen in scenarios involving
@@ -391,7 +397,12 @@ func (dsm *deleteSnapshotMutation) End(step deploy.Step, successful bool) error
 	return dsm.manager.mutate(func() bool {
 		dsm.manager.markOperationComplete(step.Old())
 		if successful {
-			contract.Assert(!step.Old().Protect)
+			// Either old should not be protected or this is a replace
+			contract.Assert(
+				!step.Old().Protect ||
+					step.Op() == deploy.OpDiscardReplaced ||
+					step.Op() == deploy.OpDeleteReplaced)
+
 			if !step.Old().PendingReplacement {
 				dsm.manager.markDone(step.Old())
 			}
