@@ -27,6 +27,7 @@ import (
 	"github.com/pulumi/pulumi/pkg/v3/resource/graph"
 	"github.com/pulumi/pulumi/sdk/v3/go/common/diag"
 	"github.com/pulumi/pulumi/sdk/v3/go/common/resource"
+	"github.com/pulumi/pulumi/sdk/v3/go/common/resource/config"
 	"github.com/pulumi/pulumi/sdk/v3/go/common/resource/plugin"
 	"github.com/pulumi/pulumi/sdk/v3/go/common/tokens"
 	"github.com/pulumi/pulumi/sdk/v3/go/common/util/contract"
@@ -62,6 +63,7 @@ type Options struct {
 	UseLegacyDiff             bool           // whether or not to use legacy diffing behavior.
 	DisableResourceReferences bool           // true to disable resource reference support.
 	DisableOutputValues       bool           // true to disable output value support.
+	ExperimentalPlans         bool           // true to enable experimental plan support.
 }
 
 // DegreeOfParallelism returns the degree of parallelism that should be used during the
@@ -145,6 +147,36 @@ func (m *resourceMap) mapRange(callback func(urn resource.URN, state *resource.S
 	})
 }
 
+type resourcePlans struct {
+	m     sync.RWMutex
+	plans Plan
+}
+
+func newResourcePlan(config config.Map) *resourcePlans {
+	return &resourcePlans{
+		plans: NewPlan(config),
+	}
+}
+
+func (m *resourcePlans) set(urn resource.URN, plan *ResourcePlan) {
+	m.m.Lock()
+	defer m.m.Unlock()
+
+	m.plans.ResourcePlans[urn] = plan
+}
+
+func (m *resourcePlans) get(urn resource.URN) (*ResourcePlan, bool) {
+	m.m.RLock()
+	defer m.m.RUnlock()
+
+	p, ok := m.plans.ResourcePlans[urn]
+	return p, ok
+}
+
+func (m *resourcePlans) plan() *Plan {
+	return &m.plans
+}
+
 // A Deployment manages the iterative computation and execution of a deployment based on a stream of goal states.
 // A running deployment emits events that indicate its progress. These events must be used to record the new state
 // of the deployment target.
@@ -153,6 +185,7 @@ type Deployment struct {
 	target               *Target                          // the deployment target.
 	prev                 *Snapshot                        // the old resource snapshot for comparison.
 	olds                 map[resource.URN]*resource.State // a map of all old resources.
+	plan                 *Plan                            // a map of all planned resource changes, if any.
 	imports              []Import                         // resources to import, if this is an import deployment.
 	isImport             bool                             // true if this is an import deployment.
 	schemaLoader         schema.Loader                    // the schema cache for this deployment, if any.
@@ -162,7 +195,8 @@ type Deployment struct {
 	depGraph             *graph.DependencyGraph           // the dependency graph of the old snapshot.
 	providers            *providers.Registry              // the provider registry for this deployment.
 	goals                *goalMap                         // the set of resource goals generated by the deployment.
-	news                 *resourceMap                     // the set of new resources generated by the deployment.
+	news                 *resourceMap                     // the set of new resources generated by the deployment
+	newPlans             *resourcePlans                   // the set of new resource plans.
 }
 
 // addDefaultProviders adds any necessary default provider definitions and references to the given snapshot. Version
@@ -300,7 +334,7 @@ func buildResourceMap(prev *Snapshot, preview bool) ([]*resource.State, map[reso
 //
 // Note that a deployment uses internal concurrency and parallelism in various ways, so it must be closed if for some
 // reason it isn't carried out to its final conclusion. This will result in cancellation and reclamation of resources.
-func NewDeployment(ctx *plugin.Context, target *Target, prev *Snapshot, source Source,
+func NewDeployment(ctx *plugin.Context, target *Target, prev *Snapshot, plan *Plan, source Source,
 	localPolicyPackPaths []string, preview bool, backendClient BackendClient) (*Deployment, error) {
 
 	contract.Assert(ctx != nil)
@@ -344,6 +378,7 @@ func NewDeployment(ctx *plugin.Context, target *Target, prev *Snapshot, source S
 		ctx:                  ctx,
 		target:               target,
 		prev:                 prev,
+		plan:                 plan,
 		olds:                 olds,
 		source:               source,
 		localPolicyPackPaths: localPolicyPackPaths,
@@ -352,6 +387,7 @@ func NewDeployment(ctx *plugin.Context, target *Target, prev *Snapshot, source S
 		providers:            reg,
 		goals:                newGoals,
 		news:                 newResources,
+		newPlans:             newResourcePlan(target.Config),
 	}, nil
 }
 
@@ -406,7 +442,7 @@ func (d *Deployment) generateEventURN(event SourceEvent) resource.URN {
 }
 
 // Execute executes a deployment to completion, using the given cancellation context and running a preview or update.
-func (d *Deployment) Execute(ctx context.Context, opts Options, preview bool) result.Result {
+func (d *Deployment) Execute(ctx context.Context, opts Options, preview bool) (*Plan, result.Result) {
 	deploymentExec := &deploymentExecutor{deployment: d}
 	return deploymentExec.Execute(ctx, opts, preview)
 }
