@@ -1,4 +1,4 @@
-// Copyright 2016-2019, Pulumi Corporation.
+// Copyright 2016-2022, Pulumi Corporation.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -16,6 +16,7 @@
 package passphrase
 
 import (
+	cryptorand "crypto/rand"
 	"encoding/base64"
 	"encoding/json"
 	"errors"
@@ -27,7 +28,9 @@ import (
 	"sync"
 
 	"github.com/pulumi/pulumi/pkg/v3/secrets"
+	"github.com/pulumi/pulumi/sdk/v3/go/common/diag"
 	"github.com/pulumi/pulumi/sdk/v3/go/common/resource/config"
+	"github.com/pulumi/pulumi/sdk/v3/go/common/util/cmdutil"
 	"github.com/pulumi/pulumi/sdk/v3/go/common/util/contract"
 )
 
@@ -111,88 +114,93 @@ func (sm *localSecretsManager) Encrypter() (config.Encrypter, error) {
 var lock sync.Mutex
 var cache map[string]secrets.Manager
 
-func NewPassphaseSecretsManager(phrase string, state string) (secrets.Manager, error) {
-	// check the cache first, if we have already seen this state before, return a cached value.
+// clearCachedSecretsManagers is used to clear the cache, for tests.
+func clearCachedSecretsManagers() {
 	lock.Lock()
+	defer lock.Unlock()
+	cache = nil
+}
+
+// getCachedSecretsManager returns a cached secret manager and true, or nil and false if not in the cache.
+func getCachedSecretsManager(state string) (secrets.Manager, bool) {
+	lock.Lock()
+	defer lock.Unlock()
+	sm, ok := cache[state]
+	return sm, ok
+}
+
+// setCachedSecretsManager saves a secret manager in the cache.
+func setCachedSecretsManager(state string, sm secrets.Manager) {
+	lock.Lock()
+	defer lock.Unlock()
 	if cache == nil {
 		cache = make(map[string]secrets.Manager)
 	}
-	cachedValue := cache[state]
-	lock.Unlock()
+	cache[state] = sm
+}
 
-	if cachedValue != nil {
-		return cachedValue, nil
+func NewPassphaseSecretsManager(phrase string, state string) (secrets.Manager, error) {
+	// Check the cache first, if we have already seen this state before, return a cached value.
+	if cached, ok := getCachedSecretsManager(state); ok {
+		return cached, nil
 	}
 
-	// wasn't in the cache so try to construct it and add it if there's no error.
+	// Wasn't in the cache so try to construct it and add it if there's no error.
 	crypter, err := symmetricCrypterFromPhraseAndState(phrase, state)
 	if err != nil {
 		return nil, err
 	}
-
-	lock.Lock()
-	defer lock.Unlock()
 	sm := &localSecretsManager{
 		crypter: crypter,
 		state: localSecretsManagerState{
 			Salt: state,
 		},
 	}
-	cache[state] = sm
+	setCachedSecretsManager(state, sm)
 	return sm, nil
 }
 
-// Tries to find the Passphrase first using `PULUMI_CONFIG_PASSPHRASE` then
-// `PULUMI_CONFIG_PASSPHRASE_FILE` if it is not found and defaulting to an empty string
-func getConfigPassphrase() (string, bool, error) {
-	if passphrase, isOk := os.LookupEnv("PULUMI_CONFIG_PASSPHRASE"); isOk {
-		return passphrase, true, nil
+// NewPromptingPassphraseSecretsManager returns a new passphrase-based secrets manager, from the
+// given state. Will use the passphrase found in PULUMI_CONFIG_PASSPHRASE, the file specified by
+// PULUMI_CONFIG_PASSPHRASE_FILE, or otherwise will prompt for the passphrase if interactive.
+func NewPromptingPassphraseSecretsManager(state string) (secrets.Manager, error) {
+	// Check the cache first, if we have already seen this state before, return a cached value.
+	if cached, ok := getCachedSecretsManager(state); ok {
+		return cached, nil
 	}
 
-	if phraseFile, isOk := os.LookupEnv("PULUMI_CONFIG_PASSPHRASE_FILE"); isOk {
-		phraseFilePath, err := filepath.Abs(phraseFile)
-		if err != nil {
-			return "", false, fmt.Errorf("unable to detect passphrase path: %w", err)
+	// Otherwise, prompt for the password.
+	const prompt = "Enter your passphrase to unlock config/secrets\n" +
+		"    (set PULUMI_CONFIG_PASSPHRASE or PULUMI_CONFIG_PASSPHRASE_FILE to remember)"
+	for {
+		phrase, interactive, phraseErr := readPassphrase(prompt, true /*useEnv*/)
+		if phraseErr != nil {
+			return nil, phraseErr
 		}
 
-		phraseDetails, err := ioutil.ReadFile(phraseFilePath)
-		if err != nil {
-			return "", false, fmt.Errorf("unable to read PULUMI_CONFIG_PASSPHRASE_FILE: %w", err)
+		sm, smerr := NewPassphaseSecretsManager(phrase, state)
+		switch {
+		case interactive && smerr == ErrIncorrectPassphrase:
+			cmdutil.Diag().Errorf(diag.Message("", "incorrect passphrase"))
+			continue
+		case smerr != nil:
+			return nil, smerr
+		default:
+			return sm, nil
 		}
-
-		return strings.TrimSpace(string(phraseDetails)), true, nil
 	}
-
-	return "", false, nil
 }
 
 // NewPassphaseSecretsManagerFromState returns a new passphrase-based secrets manager, from the
-// given state. Will use the passphrase found in PULUMI_CONFIG_PASSPHRASE.
-func NewPassphaseSecretsManagerFromState(state json.RawMessage) (secrets.Manager, error) {
+// given state. Will use the passphrase found in PULUMI_CONFIG_PASSPHRASE, the file specified by
+// PULUMI_CONFIG_PASSPHRASE_FILE, or otherwise will prompt for the passphrase if interactive.
+func NewPromptingPassphaseSecretsManagerFromState(state json.RawMessage) (secrets.Manager, error) {
 	var s localSecretsManagerState
 	if err := json.Unmarshal(state, &s); err != nil {
 		return nil, fmt.Errorf("unmarshalling state: %w", err)
 	}
 
-	// This is not ideal, but we don't have a great way to prompt the user in this case, since this may be
-	// called during an update when trying to read stack outputs as part servicing a StackReference request
-	// (since we need to decrypt the deployment)
-	phrase, isFound, err := getConfigPassphrase()
-	if err != nil {
-		return nil, err // this is already a wrapped error from getConfigPassphrase()
-	}
-
-	// At this point, we don't know if it's an incorrect passphrase. We only know if there is a passphrase or there is
-	// not. Ideally, we would prompt the user for the passphrase at this point but we can't do that in the CLI is in an
-	// update operation, so we should at least error out with an appropriate message here to ensure that the user
-	// understands why the operation fails unexpectedly.
-	if !isFound {
-		return nil, errors.New("unable to find either `PULUMI_CONFIG_PASSPHRASE` or " +
-			"`PULUMI_CONFIG_PASSPHRASE_FILE` when trying to access the Passphrase Secrets Provider; please ensure one " +
-			"of these environment variables is set to allow the operation to continue")
-	}
-
-	sm, err := NewPassphaseSecretsManager(phrase, s.Salt)
+	sm, err := NewPromptingPassphraseSecretsManager(s.Salt)
 	switch {
 	case err == ErrIncorrectPassphrase:
 		return newLockedPasspharseSecretsManager(s), nil
@@ -203,6 +211,95 @@ func NewPassphaseSecretsManagerFromState(state json.RawMessage) (secrets.Manager
 	}
 }
 
+// PromptForNewPassphrase prompts for a new passphrase, and returns the state and the secrets manager.
+func PromptForNewPassphrase(rotate bool) (string, secrets.Manager, error) {
+	var phrase string
+
+	// Get a the passphrase from the user, ensuring that they match.
+	for {
+		firstMessage := "Enter your passphrase to protect config/secrets"
+		if rotate {
+			firstMessage = "Enter your new passphrase to protect config/secrets"
+
+			if !isInteractive() {
+				return "", nil, fmt.Errorf("passphrase rotation requires an interactive terminal")
+			}
+		}
+		// Here, the stack does not have an EncryptionSalt, so we will get a passphrase and create one
+		first, _, err := readPassphrase(firstMessage, !rotate)
+		if err != nil {
+			return "", nil, err
+		}
+		secondMessage := "Re-enter your passphrase to confirm"
+		if rotate {
+			secondMessage = "Re-enter your new passphrase to confirm"
+		}
+		second, _, err := readPassphrase(secondMessage, !rotate)
+		if err != nil {
+			return "", nil, err
+		}
+
+		if first == second {
+			phrase = first
+			break
+		}
+		// If they didn't match, print an error and try again
+		cmdutil.Diag().Errorf(diag.Message("", "passphrases do not match"))
+	}
+
+	// Produce a new salt.
+	salt := make([]byte, 8)
+	_, err := cryptorand.Read(salt)
+	contract.AssertNoErrorf(err, "could not read from system random")
+
+	// Encrypt a message and store it with the salt so we can test if the password is correct later.
+	crypter := config.NewSymmetricCrypterFromPassphrase(phrase, salt)
+	msg, err := crypter.EncryptValue("pulumi")
+	contract.AssertNoError(err)
+
+	// Encode the salt as the passphrase secrets manager state.
+	state := fmt.Sprintf("v1:%s:%s", base64.StdEncoding.EncodeToString(salt), msg)
+
+	// Create the secrets manager using the state.
+	sm, err := NewPassphaseSecretsManager(phrase, state)
+	if err != nil {
+		return "", nil, err
+	}
+
+	// Return both the state and the secrets manager.
+	return state, sm, nil
+}
+
+func readPassphrase(prompt string, useEnv bool) (phrase string, interactive bool, err error) {
+	if useEnv {
+		if phrase, ok := os.LookupEnv("PULUMI_CONFIG_PASSPHRASE"); ok {
+			return phrase, false, nil
+		}
+		if phraseFile, ok := os.LookupEnv("PULUMI_CONFIG_PASSPHRASE_FILE"); ok {
+			phraseFilePath, err := filepath.Abs(phraseFile)
+			if err != nil {
+				return "", false, fmt.Errorf("unable to construct a path the PULUMI_CONFIG_PASSPHRASE_FILE: %w", err)
+			}
+			phraseDetails, err := ioutil.ReadFile(phraseFilePath)
+			if err != nil {
+				return "", false, fmt.Errorf("unable to read PULUMI_CONFIG_PASSPHRASE_FILE: %w", err)
+			}
+			return strings.TrimSpace(string(phraseDetails)), false, nil
+		}
+		if !isInteractive() {
+			return "", false, errors.New("passphrase must be set with PULUMI_CONFIG_PASSPHRASE or " +
+				"PULUMI_CONFIG_PASSPHRASE_FILE environment variables")
+		}
+	}
+	phrase, err = cmdutil.ReadConsoleNoEcho(prompt)
+	return phrase, true, err
+}
+
+func isInteractive() bool {
+	test, ok := os.LookupEnv("PULUMI_TEST_PASSPHRASE")
+	return cmdutil.Interactive() || ok && cmdutil.IsTruthy(test)
+}
+
 // newLockedPasspharseSecretsManager returns a Passphrase secrets manager that has the correct state, but can not
 // encrypt or decrypt anything. This is helpful today for some cases, because we have operations that roundtrip
 // checkpoints and we'd like to continue to support these operations even if we don't have the correct passphrase. But
