@@ -161,6 +161,8 @@ export function run(
     const tsConfigPath: string = process.env["PULUMI_NODEJS_TSCONFIG_PATH"] ?? defaultTsConfigPath;
     const skipProject = !fs.existsSync(tsConfigPath);
 
+    const transpileOnly = (process.env["PULUMI_NODEJS_TRANSPILE_ONLY"] ?? "false") === "true";
+
     let compilerOptions: object;
     try {
         const tsConfigString = fs.readFileSync(tsConfigPath).toString();
@@ -172,7 +174,7 @@ export function run(
 
     if (typeScript) {
         tsnode.register({
-            typeCheck: true,
+            transpileOnly,
             skipProject: skipProject,
             compilerOptions: {
                 target: "es6",
